@@ -27,6 +27,7 @@ cd ..
 
 OCAMLDUCE_BYTE="otherlibs/ocamlduce/ocamlduce.cma"
 OCAMLDUCE_NATIVE="otherlibs/ocamlduce/ocamlduce.cmxa"
+OCAMLDUCE_SHARED="otherlibs/ocamlduce/ocamlduce.cmxs"
 
 INI_TARGETS="ocamlc tools/ocamldep.byte"
 ALL_TARGETS="$TOPLEVEL $OCAMLDUCE_BYTE $TOOLS_BYTE $OCAMLDOC_BYTE"
@@ -36,6 +37,10 @@ if [ x"$HAS_NATIVE" = x"y" ]; then
   ALL_TARGETS="$ALL_TARGETS $OCAMLDUCE_NATIVE $TOOLS_NATIVE $OCAMLDOC_NATIVE"
 fi
 
+OCAML_STDLIB_DIR="$(ocamlc -where)"
+find "${OCAML_STDLIB_DIR}/ocamldoc" -type f | sed "s@^${OCAML_STDLIB_DIR}/@@" > ocamlducedoc.itarget
+ALL_TARGETS="$ALL_TARGETS ocamlducedoc.otarget"
+
 set -x
 
 if [ x"$BOOT_MODE" = x"y" ]; then
@@ -51,4 +56,5 @@ cp -p _build/tools/ocamldep.byte _build/tools/ocamldep
 if [ x"$HAS_NATIVE" = x"y" ]; then
   rm -f _build/tools/ocamldep.opt
   cp -p _build/tools/ocamldep.native _build/tools/ocamldep.opt
+  ocamlopt -shared -linkall -o "_build/$OCAMLDUCE_SHARED" "_build/$OCAMLDUCE_NATIVE"
 fi
